#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-io
version:              0.2.0
visibility:           public
id:                   quickcheck-io-0.2.0-640oBmmwYAJEWQ2pLK5MOs
key:                  quickcheck-io-0.2.0-640oBmmwYAJEWQ2pLK5MOs
license:              MIT
copyright:            (c) 2013-2017 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/quickcheck-io#readme
synopsis:             Use HUnit assertions as QuickCheck properties
description:
    This package provides an orphan instance that allows you to
    use HUnit assertions as QuickCheck properties.

category:             Testing
abi:                  aa380e9f746913d3c999493d76351107
exposed:              True
exposed-modules:      Test.QuickCheck.IO
hidden-modules:       Paths_quickcheck_io
import-dirs:          /usr/lib/ghc-9.6.6/site-local/quickcheck-io-0.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/quickcheck-io-0.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/quickcheck-io-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-io
hs-libraries:         HSquickcheck-io-0.2.0-640oBmmwYAJEWQ2pLK5MOs
depends:
    HUnit-1.6.2.0-LGIxg4a8Z6lDFuBrLZEGZ
    QuickCheck-2.15.0.1-fyQWEOVjQY85EPR3Jn9YV base-4.18.2.1

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-io/html/quickcheck-io.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-io/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

